@@ -1,7 +1,7 @@
 from judgeval.data.example import Example, ExampleParams
 from judgeval.data.scorer_data import ScorerData, create_scorer_data
 from judgeval.data.result import ScoringResult, generate_scoring_result
-from judgeval.data.trace import Trace, TraceSpan, TraceUsage
+from judgeval.data.trace import TraceUsage
 
 
 __all__ = [
@@ -11,7 +11,5 @@ __all__ = [
     "create_scorer_data",
     "ScoringResult",
     "generate_scoring_result",
-    "Trace",
-    "TraceSpan",
     "TraceUsage",
 ]
