@@ -1,29 +1,27 @@
-from judgeval.scorers.api_scorer import APIScorerConfig
+from judgeval.scorers.api_scorer import (
+    APIScorerConfig,
+    ExampleAPIScorerConfig,
+    TraceAPIScorerConfig,
+)
 from judgeval.scorers.base_scorer import BaseScorer
 from judgeval.scorers.judgeval_scorers.api_scorers import (
-    ExecutionOrderScorer,
-    HallucinationScorer,
     FaithfulnessScorer,
     AnswerRelevancyScorer,
     AnswerCorrectnessScorer,
     InstructionAdherenceScorer,
-    DerailmentScorer,
-    ToolOrderScorer,
+    TracePromptScorer,
     PromptScorer,
-    ToolDependencyScorer,
 )
 
 __all__ = [
     "APIScorerConfig",
+    "ExampleAPIScorerConfig",
+    "TraceAPIScorerConfig",
     "BaseScorer",
+    "TracePromptScorer",
     "PromptScorer",
-    "ExecutionOrderScorer",
-    "HallucinationScorer",
     "FaithfulnessScorer",
     "AnswerRelevancyScorer",
     "AnswerCorrectnessScorer",
     "InstructionAdherenceScorer",
-    "DerailmentScorer",
-    "ToolOrderScorer",
-    "ToolDependencyScorer",
 ]
